==> nextcloud-15.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/twofactor_backupcodes/l10n/hu.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "activated" : "Aktivált",
    "updated" : "frissítve",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Ezek a biztonsági kódjaid. Kérlek mentsd el vagy nyomtasd ki őket úgy hogy később is meglegyenek.",
    "Save backup codes" : "Biztonsági kódok mentése",
    "Print backup codes" : "Biztonsági kódok nyomtatása",
    "Regenerate backup codes" : "Biztonsági kódok újra generálása",
    "If you regenerate backup codes, you automatically invalidate old codes." : "Ha újra generálod a biztonsági kódokat, akkor a régiek automatikusan érvénytelenítve lesznek.",
    "Generate backup codes" : "Biztonsági kód generálás",
    "An error occurred while generating your backup codes" : "Hiba történt a biztonsági kódok generálása közben",
    "Nextcloud backup codes" : "Nextcloud biztonsági kódok",
    "You created two-factor backup codes for your account" : "Kétfaktoros helyreállítási kódot hoztál létre a fiókodhoz",
    "Second-factor backup codes" : "Második lépcsős biztonsági kódok",
    "Backup code" : "Biztonsági kód",
    "Use backup code" : "Biztonsági kód használata",
    "Two factor backup codes" : "Kétfaktoros biztonsági mentési kódok",
    "A two-factor auth backup codes provider" : "Kétfaktoros azonosítás biztonsági kódok szolgáltatója",
    "Submit" : "Küldés",
    "Backup codes have been generated. {{used}} of {{total}} codes have been used." : "A biztonsági kódok elkészültek. Felhasználva: {{used}}, ennyiből: {{total}}."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/twofactor_backupcodes/l10n/hu.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Ezek a biztonsági kódjaid. Kérlek mentsd el vagy nyomtasd ki őket úgy hogy később is meglegyenek.",
    "Save backup codes" : "Biztonsági kódok mentése",
    "Print backup codes" : "Biztonsági kódok nyomtatása",
    "Regenerate backup codes" : "Biztonsági kódok újra generálása",
    "If you regenerate backup codes, you automatically invalidate old codes." : "Ha újra generálod a biztonsági kódokat, akkor a régiek automatikusan érvénytelenítve lesznek.",
    "Generate backup codes" : "Biztonsági kód generálás",
    "An error occurred while generating your backup codes" : "Hiba történt a biztonsági kódok generálása közben",
    "Nextcloud backup codes" : "Nextcloud biztonsági kódok",
    "You created two-factor backup codes for your account" : "Kétfaktoros helyreállítási kódot hoztál létre a fiókodhoz",
    "Second-factor backup codes" : "Második lépcsős biztonsági kódok",
    "Backup code" : "Biztonsági kód",
    "Use backup code" : "Biztonsági kód használata",
    "Two factor backup codes" : "Kétfaktoros biztonsági mentési kódok",
    "A two-factor auth backup codes provider" : "Kétfaktoros azonosítás biztonsági kódok szolgáltatója",
    "Submit" : "Küldés",
    "Backup codes have been generated. {{used}} of {{total}} codes have been used." : "A biztonsági kódok elkészültek. Felhasználva: {{used}}, ennyiből: {{total}}.",
    "activated" : "Aktivált",
    "updated" : "frissítve"
},
"nplurals=2; plural=(n != 1);");
